@@ -1,5 +1,5 @@
 names = [
-    "test_aqua.jl"
+    "test_code_quality.jl"
     "test_fock.jl"
     "test_nlevel.jl"
     "test_spin.jl"
@@ -28,9 +28,8 @@ names = [
     "test_measurement_backaction.jl"
 ]
 
-detected_tests = filter(
-    name->startswith(name, "test_") && endswith(name, ".jl"),
-    readdir("."))
+detected_tests =
+    filter(name->startswith(name, "test_") && endswith(name, ".jl"), readdir("."))
 
 unused_tests = setdiff(detected_tests, names)
 if length(unused_tests) != 0
@@ -42,7 +41,7 @@ if length(unavailable_tests) != 0
     error("The following tests could not be found:\n", join(unavailable_tests, "\n"))
 end
 
-for name=names
+for name in names
     if startswith(name, "test_") && endswith(name, ".jl")
         include(name)
     end
